@@ -11,9 +11,9 @@ function(N,data,h,L0,L,M,Melite,eps,a,b){
   } else {
     
   ########################Parameter initialization######################################################  
-  new_para<-rbind(rep(L0+(L-L0)/2,N),rep(sqrt(L-L0)^2/12),N)    
+  new_para<-rbind(rep(L0+(L-L0)/2,N),rep(sqrt(L-L0)^2/12,N))    
   ######################################################################################################  
-  modbic<-c()
+#  modbic<-c()
   
   k<-0
   repeat
@@ -28,7 +28,7 @@ function(N,data,h,L0,L,M,Melite,eps,a,b){
     ch<-cbind(ch,mod_bic)                         
     ch<-ch[order(ch[,(N+3)],decreasing=TRUE),]  
     melitesmpl<-ch[1:Melite,]                     
-    modbic[k]<-melitesmpl[1,(N+3)] 
+#    modbic[k]<-melitesmpl[1,(N+3)] 
     
     new_par_n<-array(0,dim=c(2,N))
     new_par_n[1,]<-apply(as.matrix(melitesmpl[,(2:(N+1))]),2,mean)
@@ -41,6 +41,7 @@ function(N,data,h,L0,L,M,Melite,eps,a,b){
     
     if(max(mad)<=eps){break}
   }
-  return(list(loci=ch[1,(1:(N+2))], mBIC=modbic[k]))
+#  return(list(loci=ch[1,(1:(N+2))], mBIC=modbic[k]))
+  return(list(loci=ch[1,(1:(N+2))], mBIC=melitesmpl[1,(N+3)]))
   }
 }
